"""인공위성 운영을 위한 모듈"""


class Satellite:
    """지구 궤도를 돌며 임무를 수행하는 인공위성"""

    @staticmethod
    def coordinates() -> str:
        """인공위성의 현 좌표

        To use:

            >>> Satellite.coordinates()
            I don't know yet.

        Todo:
            * https://gssc.esa.int/navipedia/index.php/Satellite_Coordinates
        """
        return "I don't know yet."
